==> kogito-codegen-1.1.0.Final-test-sources.jar: org/kie/kogito/codegen/ApplicationConfigGeneratorTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.kogito.codegen;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.Test;
import org.kie.kogito.codegen.process.config.ProcessConfigGenerator;
import org.mockito.Mockito;

public class ApplicationConfigGeneratorTest {

    @Test
    public void withProcessConfig() {
        final ApplicationConfigGenerator generator = new ApplicationConfigGenerator(null, "org.kie.kogito.test");
        final ProcessConfigGenerator processConfigGenerator = Mockito.mock(ProcessConfigGenerator.class);
        final ApplicationConfigGenerator returnedConfigGenerator = generator.withProcessConfig(processConfigGenerator);
        assertThat(returnedConfigGenerator)
                .isNotNull()
                .isSameAs(generator);
    }

    @Test
    public void withProcessConfigNull() {
        final ApplicationConfigGenerator generator = new ApplicationConfigGenerator(null, "org.kie.kogito.test");
        final ApplicationConfigGenerator returnedConfigGenerator = generator.withProcessConfig(null);
        assertThat(returnedConfigGenerator)
                .isNotNull()
                .isSameAs(generator);
    }

}

==> kogito-codegen-1.2.0.Final-test-sources.jar: org/kie/kogito/codegen/ApplicationConfigGeneratorTest.java <==
/*
 * Copyright 2019 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.kie.kogito.codegen;

import static org.assertj.core.api.Assertions.assertThat;

import org.junit.jupiter.api.Test;
import org.kie.kogito.codegen.context.JavaKogitoBuildContext;
import org.kie.kogito.codegen.context.KogitoBuildContext;
import org.kie.kogito.codegen.process.config.ProcessConfigGenerator;
import org.mockito.Mockito;

public class ApplicationConfigGeneratorTest {

    KogitoBuildContext context = JavaKogitoBuildContext.builder()
            .withPackageName("org.kie.kogito.test")
            .build();

    @Test
    public void withProcessConfig() {
        final ApplicationConfigGenerator generator = new ApplicationConfigGenerator(context);
        final ProcessConfigGenerator processConfigGenerator = Mockito.mock(ProcessConfigGenerator.class);
        final ApplicationConfigGenerator returnedConfigGenerator = generator.withConfigGenerator(processConfigGenerator);
        assertThat(returnedConfigGenerator)
                .isNotNull()
                .isSameAs(generator);
    }

    @Test
    public void withProcessConfigNull() {
        final ApplicationConfigGenerator generator = new ApplicationConfigGenerator(context);
        final ApplicationConfigGenerator returnedConfigGenerator = generator.withConfigGenerator(null);
        assertThat(returnedConfigGenerator)
                .isNotNull()
                .isSameAs(generator);
    }

}
